@@ -183,7 +183,8 @@ I<stop()> and I<start()> R.
 
 =item bin()
 
-Get or set the path to the R executable.
+Get or set the path to the R executable. Note that the path will be available
+only after start() has been called.
 
 =item version()
 
@@ -293,7 +294,7 @@ if ( $^O =~ m/^(?:.*?win32|dos)$/i ) {
     require Statistics::R::Win32;
 }
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 our ($SHARED_BRIDGE, $SHARED_STDIN, $SHARED_STDOUT, $SHARED_STDERR);
 
@@ -354,6 +355,7 @@ sub start {
       my $bridge = $self->_bridge;
       $status = $bridge->start or die "Error starting ".PROG.": $?\n";
       $self->bin( $bridge->{KIDS}->[0]->{PATH} );
+      delete $self->{died};
       print "DBG: Started R, ".$self->bin." (pid ".$self->pid.")\n" if DEBUG;
 
       # Generate regexp to catch R errors
@@ -384,7 +386,7 @@ sub start {
 sub stop {
    my ($self) = @_;
    my $status = 1;
-   if ( ($self->is_started) && (not $self->{died}) ) {
+   if ( $self->is_started ) {
       $status = $self->_bridge->finish or die "Error stopping ".PROG.": $?\n";
       print "DBG: Stopped R\n" if DEBUG;
    }
@@ -402,11 +404,17 @@ sub is_started {
    # Query whether or not R has been started and is still running - hackish.
    # See https://rt.cpan.org/Ticket/Display.html?id=70595
    my ($self) = @_;
+   my $is_started = 0;
    my $bridge = $self->_bridge;
-   if (not exists $bridge->{STATE}) {
-      die "Internal error: could not get STATE from IPC::Run\n";
+   if (defined $bridge && not $self->{died}) {
+      if (not exists $bridge->{STATE}) {
+         die "Internal error: could not get STATE from IPC::Run\n";
+      }
+      if ($bridge->{STATE} eq IPC::Run::_started && $bridge->pumpable) {
+         $is_started = 1;
+      }
    }
-   return ($bridge->{STATE} eq IPC::Run::_started && $bridge->pumpable) ? 1 : 0;
+   return $is_started;
 }
 
 
